pub struct BugPlanner { /* private fields */ }Expand description
Bug family path planner operating on an integer grid.
Obstacles are specified as a set of occupied grid cells. The planner precomputes the boundary cells (free cells that are 8-connected neighbours of at least one obstacle cell).
Implementations