pub struct ElasticBands {
pub bubbles: Vec<Bubble>,
/* private fields */
}Expand description
Elastic Bands planner.
Iteratively deforms a path (represented as a chain of Bubbles) to be
shorter and further from obstacles.
Fields
bubbles: Vec<Bubble>Current chain of bubbles.
Implementations
Sourceimpl ElasticBands
impl ElasticBands
Sourcepub fn new(
initial_path: &[[f64; 2]],
distance_field: DistanceField,
config: ElasticBandsConfig,
) -> Self
pub fn new( initial_path: &[[f64; 2]], distance_field: DistanceField, config: ElasticBandsConfig, ) -> Self
Create a new elastic band from an initial path and a pre-computed distance field.
Sourcepub fn from_obstacles(
initial_path: &[[f64; 2]],
obstacles: &[Vec<bool>],
config: ElasticBandsConfig,
) -> Self
pub fn from_obstacles( initial_path: &[[f64; 2]], obstacles: &[Vec<bool>], config: ElasticBandsConfig, ) -> Self
Create from an initial path and a binary obstacle grid.
Sourcepub fn update_bubbles(&mut self)
pub fn update_bubbles(&mut self)
Perform a single optimisation step: move bubbles then maintain overlap.