pub struct SweepCoveragePath {
pub x: Vec<f64>,
pub y: Vec<f64>,
}Expand description
Result of the grid-based sweep coverage path planner.
Fields
x: Vec<f64>X coordinates of the planned path in the global frame.
y: Vec<f64>Y coordinates of the planned path in the global frame.