pub struct InformedRRTStar {
pub start: Node,
pub goal: Node,
pub min_rand: f64,
pub max_rand: f64,
pub expand_dis: f64,
pub goal_sample_rate: i32,
pub max_iter: usize,
pub obstacle_list: Vec<(f64, f64, f64)>,
pub node_list: Vec<Node>,
}Fields
start: Nodegoal: Nodemin_rand: f64max_rand: f64expand_dis: f64goal_sample_rate: i32max_iter: usizeobstacle_list: Vec<(f64, f64, f64)>node_list: Vec<Node>Implementations
Sourceimpl InformedRRTStar
impl InformedRRTStar
pub fn new( start: (f64, f64), goal: (f64, f64), obstacle_list: Vec<(f64, f64, f64)>, rand_area: (f64, f64), expand_dis: f64, goal_sample_rate: i32, max_iter: usize, ) -> Self
pub fn planning(&mut self) -> Option<Vec<[f64; 2]>>
Sourcepub fn plan_from(
&mut self,
start: Point2D,
goal: Point2D,
) -> RoboticsResult<Path2D>
pub fn plan_from( &mut self, start: Point2D, goal: Point2D, ) -> RoboticsResult<Path2D>
Plan a path from the given start to goal, returning a [Path2D].
This is a convenience wrapper around planning() that accepts
[Point2D], sets the start/goal, runs the planner, and returns [Path2D].
Requires &mut self because the underlying algorithm mutates internal state.
Sourcepub fn get_obstacles(&self) -> &[(f64, f64, f64)]
pub fn get_obstacles(&self) -> &[(f64, f64, f64)]
Get the obstacle list