pub enum JPSInvalidJumpPathDetail {
InvalidStepSequence,
CostMismatch,
InvalidStepSequenceAndCostMismatch,
}Expand description
More specific classification for InvalidJumpPath.
Variants
InvalidStepSequence
The reconstructed jump path contains at least one invalid grid step.
CostMismatch
The reconstructed jump path is geometrically valid but its length no longer matches the search cost accumulated on jump points.
InvalidStepSequenceAndCostMismatch
The reconstructed jump path has both invalid steps and a cost mismatch.
Implementations