pub struct LqrRrtStar {
pub start: Node,
pub end: Node,
pub config: LqrRrtStarConfig,
pub obstacle_list: Vec<(f64, f64, f64)>,
pub node_list: Vec<Node>,
/* private fields */
}Expand description
LQR-RRT* planner.
Uses LQR trajectories for tree steering and LQR path length as the cost metric, combined with the RRT* rewiring strategy.
Fields
start: Nodeend: Nodeconfig: LqrRrtStarConfigobstacle_list: Vec<(f64, f64, f64)>node_list: Vec<Node>Implementations
Sourceimpl LqrRrtStar
impl LqrRrtStar
Sourcepub fn new(
start: (f64, f64),
goal: (f64, f64),
obstacle_list: Vec<(f64, f64, f64)>,
config: LqrRrtStarConfig,
) -> Self
pub fn new( start: (f64, f64), goal: (f64, f64), obstacle_list: Vec<(f64, f64, f64)>, config: LqrRrtStarConfig, ) -> Self
Create a new LQR-RRT* planner.
Sourcepub fn planning(&mut self) -> Option<Vec<[f64; 2]>>
pub fn planning(&mut self) -> Option<Vec<[f64; 2]>>
Run the LQR-RRT* planning algorithm.
Returns a path as a vector of [x, y] pairs (goal to start order),
or None if no path is found.
Sourcepub fn plan_from(
&mut self,
start: Point2D,
goal: Point2D,
) -> RoboticsResult<Path2D>
pub fn plan_from( &mut self, start: Point2D, goal: Point2D, ) -> RoboticsResult<Path2D>
Plan a path from start to goal, returning a [Path2D].
Sourcepub fn get_obstacles(&self) -> &[(f64, f64, f64)]
pub fn get_obstacles(&self) -> &[(f64, f64, f64)]
Get the obstacle list.