StateLattice

pub struct StateLattice { /* private fields */ }
State Lattice Planner

Implementations

Source

impl StateLattice

pub fn new(config: StateLatticeConfig) -> Self

pub fn with_defaults() -> Self

pub fn set_lookup_table_from_csv(&mut self, csv_data: &str)

Set lookup table from CSV data

pub fn set_initial_curvature(&mut self, k0: f64)

Set initial curvature

pub fn config(&self) -> &StateLatticeConfig

Get configuration

pub fn calc_uniform_polar_states(&self) -> Vec<TargetPose>

Calculate uniform polar states

pub fn calc_biased_polar_states(&self, goal_angle: f64) -> Vec<TargetPose>

Calculate biased polar states toward a goal

pub fn calc_lane_states(&self) -> Vec<TargetPose>

Calculate lane states for structured driving

pub fn generate_paths(&self, targets: &[TargetPose]) -> Vec<Trajectory>

Generate paths to target states

pub fn plan_uniform_polar(&self) -> Vec<Trajectory>

Generate paths using uniform polar sampling

pub fn plan_biased_polar(&self, goal_angle: f64) -> Vec<Trajectory>

Generate paths using biased polar sampling

pub fn plan_lane_states(&self) -> Vec<Trajectory>

Generate paths using lane sampling

pub fn plan( &self, start: Point2D, goal: Point2D, ) -> Result<Path2D, RoboticsError>

Plan a path from start to goal using state lattice

pub fn plan_with_obstacles( &self, goal: Point2D, obstacles: &Obstacles, robot_radius: f64, ) -> Result<ObstacleAwarePlanResult, RoboticsError>

Plan the best collision-free trajectory considering obstacles.

Generates candidate trajectories using biased polar sampling toward the goal, checks each against obstacles, scores them, and returns the best collision-free trajectory.

All coordinates are in the ego frame (vehicle at origin heading along +x). Transform obstacles into the ego frame before calling.

pub fn plan_from_pose_with_obstacles( &self, pose_x: f64, pose_y: f64, pose_yaw: f64, goal: Point2D, obstacles: &Obstacles, robot_radius: f64, ) -> Result<ObstacleAwarePlanResult, RoboticsError>

Plan from a world-frame pose with obstacles, returning a world-frame result.

Transforms obstacles into the ego frame, plans, then transforms the result back to world frame.