pub struct TangentBugResult {
pub path_x: Vec<f64>,
pub path_y: Vec<f64>,
}Expand description
The planned path returned by TangentBugPlanner::plan.
Fields
path_x: Vec<f64>X coordinates of the path, from start to goal.
path_y: Vec<f64>Y coordinates of the path, from start to goal.