pub struct SpaceTimeAStar;Expand description
Space-Time A* planner for a single agent on a grid with dynamic obstacles.
The cost g(n) is the number of time steps taken to reach a node, and the
heuristic is the Manhattan distance to the goal.
Implementations