clearance_map

Function clearance_map 

pub fn clearance_map(
    cells: &[Vec<TerrainRiskCell>],
    cell_size: f64,
) -> RoboticsResult<Vec<Vec<f64>>>
Compute Euclidean clearance from every cell to the nearest blocked cell.

Distances are returned in metric units using cell_size. If the grid has no blocked cells, every clearance value is f64::INFINITY.